@@ -1,4 +1,4 @@
-/* $Id: ending.c,v 1.7 2003/01/12 01:55:43 oohara Exp $ */
+/* $Id: ending.c,v 1.9 2012/01/29 04:04:15 oohara Exp $ */
 
 #include <stdio.h>
 /* strlen */
@@ -30,7 +30,7 @@ ending(int t)
     if (tenm_table_add(message_new(190.0, 240.0,
                                    0.0, 0.0, 200, "all cleared", 11)) < 0)
     {
-      fprintf(stderr, "ending: cannot create message (line 2) "
+      fprintf(stderr, "ending: cannot create message (line 1) "
               "(t = %d)\n", t);
       status = SCHEDULER_ERROR;
     }
@@ -50,5 +50,5 @@ ending(int t)
   if (t == 240)
     return SCHEDULER_NEXT_STAGE;
 
-  return SCHEDULER_SUCCESS;
+  return status;
 }
