@@ -1,4 +1,4 @@
-/* $Id: normal-enemy.c,v 1.98 2003/08/19 23:26:35 oohara Exp $ */
+/* $Id: normal-enemy.c,v 1.99 2004/02/15 14:39:46 oohara Exp $ */
 
 #include <stdio.h>
 /* malloc, rand */
@@ -25,6 +25,7 @@
 
 #define COUNT_MODE_BEGIN 16
 #define COUNT_D_MODE_BEGIN 10
+#define NEAR_ZERO 0.0001
 
 static int normal_enemy_hit_point(int what);
 static int normal_enemy_move(tenm_object *my, double turn_per_frame);
@@ -416,6 +417,8 @@ normal_enemy_new(double x, double y, int what, int type, int color,
     r_x = x - count_d[4];
     r_y = y - count_d[5];
     r_length = tenm_sqrt((int) (r_x * r_x + r_y * r_y));
+    if (r_length < NEAR_ZERO)
+      r_length = 1.0;
     r_x /= r_length;
     r_y /= r_length;
     
@@ -429,6 +432,8 @@ normal_enemy_new(double x, double y, int what, int type, int color,
     r_y_temp = y + count_d[9] * dr_y * temp - count_d[5];
     r_length_temp = tenm_sqrt((int) (r_x_temp * r_x_temp
                                      + r_y_temp * r_y_temp));
+    if (r_length_temp < NEAR_ZERO)
+      r_length_temp = 1.0;
     count_d[8] -= r_length_temp - r_length;
 
     count_d[0] = count_d[6]
@@ -761,6 +766,8 @@ normal_enemy_act(tenm_object *my, const tenm_object *player)
     r_x = my->x - my->count_d[4];
     r_y = my->y - my->count_d[5];
     r_length = tenm_sqrt((int) (r_x * r_x + r_y * r_y));
+    if (r_length < NEAR_ZERO)
+      r_length = 1.0;
     r_x /= r_length;
     r_y /= r_length;
 
@@ -910,6 +917,8 @@ normal_enemy_act(tenm_object *my, const tenm_object *player)
       r_x = my->x - my->count_d[4];
       r_y = my->y - my->count_d[5];
       r_length = tenm_sqrt((int) (r_x * r_x + r_y * r_y));
+      if (r_length < NEAR_ZERO)
+        r_length = 1.0;
       r_x /= r_length;
       r_y /= r_length;
 
@@ -923,6 +932,8 @@ normal_enemy_act(tenm_object *my, const tenm_object *player)
       r_y_temp = my->y + my->count_d[9] * dr_y * temp - my->count_d[5];
       r_length_temp = tenm_sqrt((int) (r_x_temp * r_x_temp
                                      + r_y_temp * r_y_temp));
+      if (r_length_temp < NEAR_ZERO)
+        r_length_temp = 1.0;
       my->count_d[8] -= r_length_temp - r_length;
 
       my->count_d[0] = my->count_d[6]
