@@ -1,13 +1,19 @@
-/* $Id: bac_lexical.h,v 1.3 2003/01/11 19:49:48 oohara Exp $ */
+/* $Id: bac_lexical.h,v 1.6 2012/01/29 03:59:31 oohara Exp $ */
 
 #ifndef __BAC_LEXICAL_H__
 #define __BAC_LEXICAL_H__
 
+/* FILE */
+#include <stdio.h>
+
+/* yylineno */
+extern int bac_lineno;
+
 /* yylex */
 int bac_lex(void);
+/* yylex_destroy */
+int bac_lex_destroy(void);
 
-int bac_get_line_number(void);
-void bac_clear_line_number(void);
 void bac_read_from_file(FILE *file);
 void bac_read_from_string(const char *string);
 void bac_close_string(void);
